@@ -1,3 +1,4 @@
+/* -*- c++ -*- (enables emacs c++ mode)                                    */
 /* *********************************************************************** */
 /*                                                                         */
 /* Library :  Dynamic Array Library (dal)                                  */
@@ -34,6 +35,7 @@
 
 
 #include <dal_std.h>
+#include <dal_except.h>
 #include <functional>
 
 namespace dal
