@@ -1,3 +1,4 @@
+/* -*- c++ -*- (enables emacs c++ mode)                                    */
 /* *********************************************************************** */
 /*                                                                         */
 /* Library :  Dynamic Array Library (dal)                                  */
@@ -237,8 +238,10 @@ namespace dal
       void swap(bit_vector &da);
       void clear(void);
       void swap(size_type i1, size_type i2);
-      size_type memsize(void) const
-      {	return bit_container::memsize() + sizeof(bit_vector); }
+      size_type memsize(void) const {
+	return bit_container::memsize() + sizeof(bit_vector) 
+	  - sizeof(bit_container);
+      }
       size_type card(void) const;
       size_type first_true(void) const;
       size_type first_false(void) const;
