@@ -33,10 +33,9 @@
 #define __GETFEM_FEM_H
 
 #include <bgeot_geometric_trans.h>
-#include <bgeot_integration.h>
-#include <getfem_config.h>
+#include <getfem_integration.h>
+#include <getfem_poly_composite.h>
 #include <getfem_precomp.h>
-//#include <getfem_mesh.h>
 #include <deque>
 
 namespace getfem
@@ -66,7 +65,6 @@ namespace getfem
   /// Product description of the descriptions *pnd1 and *pnd2.
   pdof_description product_dof(pdof_description, pdof_description);
   
-  pdof_description change_coord_index_dof(pdof_description, dim_type);
   /** Gives a total order on the dof description compatible with the
    *   identification.
    */
@@ -80,50 +78,6 @@ namespace getfem
   /*	Classes for description of a finite element.                      */
   /* ******************************************************************** */
   
-  /** Describe a finite element method on a reference element. At the
-   *  level of the description of nodes, basic functions, ...
-   *  This class is not to be manipulate by itself. Use pfem\_interpolation
-   *  and the functions written to produce the descriptions from the
-   *  basic descriptions.
-   *   \subsubsection{General finite element method}
-   *   A general finite element method is described by the set of the
-   *   three following things:
-   *   \begin{itemize}
-   *      \item An element $T$ (geometric figure, polyhedric and convex),
-   *      \item A functional vectorial space $V$, of finite dimension $n_d$,
-   *      \item A set of $n_d$ linear functional \\
-   *    $ l_i : V \longrightarrow {I\hspace{-0.3em}R}, \ \ \ i = 1..n_g. $ \\
-   *   \end{itemize}
-   *   Very often, each linear functional $l_i$ will be associated with
-   *   a node $a^i$, which is a particular point of $T$. \\
-   *   The shape functions of the finite element are the functions
-   *   $\varphi_i \in V$ which satisfy \\
-   *   $ l_i(\varphi_j) = \delta_{ij}, i,j = 1..n_g. $
-   *   The finite element is said "unisolvant" when the set of shape functions
-   *   are uniquely defined. \\
-   *   Often $V$ is a space of polynomials, but not always. \\
-   *   
-   *   \subsubsection{Considered finite element methods}
-   *   The finite element methods treaten in {\sc Getfem++}, are
-   *   the methods satisfying the following assumptions :
-   *  
-   *   \begin{itemize}
-   *     \item the method is equivalent throw a polynomial geometric
-   *       transformation to a method defined on a reference element.
-   *       This means that there exist a reference element $\overline{T}$, and
-   *       a transformation \\
-   *       $ \begin{array}{rcl} \tau : \overline{T} &\longrightarrow& T, \\
-   *          \overline{x} &\longmapsto& x, \end{array} $ \\
-   *       which is polynomial.
-   *     \item An additionnal linear transformation is allowed: \\
-   *     $ \tilde{\varphi}_i(x) =  \overline{\varphi}_i(\tau(\overline{x})),$\\
-   *     and  \\
-   *     $ \varphi_i = \sum_{j = 1}^{n_d} \tilde{M}_{ij} \tilde{\varphi}_j $\\
-   *     This additionnal matrix may be dependant on the real element and allow
-   *     non-equivalent element such as Hermite elements. (...)
-   *   \end{itemize}
-   */
-  
   class virtual_fem;
   typedef const virtual_fem * pfem;
   
@@ -138,11 +92,8 @@ namespace getfem
     mutable bool pspt_valid;
     bgeot::pconvex_ref cvr; // reference element.
     dim_type ntarget_dim;
-    bool is_equiv, is_lag, is_pol, do_grad;
-    short_type es_degree;
-    
-    void add_node(const pdof_description &d, const base_node &pt) ;
-    void init_cvs_node(void);
+    bool is_equiv, is_lag, is_pol, do_grad, is_polycomp;
+    short_type es_degree, hier_raff;
     
   public :
     /// Number of degrees of freedom.
@@ -156,6 +107,7 @@ namespace getfem
     /// Gives the array of pointer on dof description.
     const std::vector<pdof_description> &dof_types(void) const 
       { return _dof_types; }
+    short_type hierarchical_raff(void) const { return hier_raff; }
     /// dimension of the reference element.
     dim_type dim(void) const { return cvr->structure()->dim(); }
     /// dimension of the target space.
@@ -167,8 +119,8 @@ namespace getfem
     bgeot::pconvex_structure basic_structure(void) const
       { return cvr->structure(); }
     /// Gives the convex of the reference element.
-    bgeot::pconvex_ref ref_convex(void) const
-      { return cvr; }
+    bgeot::pconvex_ref ref_convex(void) const { return cvr; }
+    bgeot::pconvex_ref &ref_convex(void) { return cvr; }
     /// Gives the convex representing the nodes on the reference element.
     const bgeot::convex<base_node> &node_convex(void) const
       { return cv_node; }
@@ -185,7 +137,13 @@ namespace getfem
     bool is_equivalent(void) const { return is_equiv; }
     bool is_lagrange(void) const { return is_lag; }
     bool is_polynomial(void) const { return is_pol; }
+    bool is_polynomialcomp(void) const { return is_polycomp; }
+    bool &is_polynomialcomp(void) { return is_polycomp; }
+    bool &is_equivalent(void) { return is_equiv; }
+    bool &is_lagrange(void) { return is_lag; }
+    bool &is_polynomial(void) { return is_pol; }
     short_type estimated_degree(void) const { return es_degree; }
+    short_type &estimated_degree(void) { return es_degree; }
     virtual void mat_trans(base_matrix &, const base_matrix &,
 			   bgeot::pgeometric_trans) const
       { DAL_THROW(internal_error, "This function should not be called."); }
@@ -230,10 +188,34 @@ namespace getfem
     bool do_grad_reduction(void) const { return do_grad; }
 
     virtual_fem(void) { 
-      ntarget_dim = 1; is_equiv = is_pol = is_lag = false;
-      pspt_valid = false; do_grad = true;
+      ntarget_dim = 1; is_equiv = is_pol = is_polycomp = is_lag = false;
+      pspt_valid = false; do_grad = true; hier_raff = 0; 
     }
 
+    void add_node(const pdof_description &d, const base_node &pt) ;
+    void init_cvs_node(void);
+    void unfreeze_cvs_node(void);
+
+    virtual_fem &operator =(const virtual_fem &f) {
+      _dof_types = f._dof_types;
+      cvs_node = f.cvs_node;
+      cv_node = f.cv_node;
+      cv_node.structure() = &(cvs_node);
+      pspt = 0;
+      pspt_valid = false;
+      cvr = f.cvr;
+      ntarget_dim = f.ntarget_dim;
+      is_equiv = f.is_equiv;
+      is_lag = f.is_lag;
+      is_pol = f.is_pol;
+      is_polycomp = f.is_polycomp;
+      do_grad = f.do_grad;
+      es_degree = f.es_degree;
+      hier_raff = f.hier_raff;
+      return *this;
+    }
+    virtual_fem(const virtual_fem &f) { *this = f; }
+
     virtual ~virtual_fem() {}
 
   };
@@ -250,6 +232,7 @@ namespace getfem
     
     /// Gives the array of basic functions (components).
     const std::vector<FUNC> &base(void) const { return _base; }
+    std::vector<FUNC> &base(void) { return _base; }
     
     void interpolation(const base_node &x, const base_matrix &G, 
 		       bgeot::pgeometric_trans pgt,
@@ -300,6 +283,7 @@ namespace getfem
   };
   
   typedef const fem<base_poly> * ppolyfem;
+  typedef const fem<polynomial_composite> * ppolycompfem;
   
   template <class FUNC>
   void fem<FUNC>::interpolation(const base_node &x, const base_matrix &G,
@@ -366,11 +350,6 @@ namespace getfem
 	} 
   }
   
-  
-  /** @name functions on convex structures
-   */
-  //@{
-  
   /** Gives a pointer on the structures describing the more classical fem
    *  of degree k on a geometric convex cvs (coming from the geometric trans).
    */
@@ -378,21 +357,40 @@ namespace getfem
 
   pfem fem_descriptor(std::string name);
   /*  List of elements :
-   *  "FEM_PK(N,K)" classical Lagrange element PK on a simplex
-   *  "FEM_PK_DISCONTINUOUS(N,K)" discontinuous Lagrange element PK on simplex
-   *  "FEM_QK(N,K)" classical Lagrange element QK on a parellepiped
-   *  "FEM_PK_PRISM(N,K)" classical Lagrange element PK on a prism
-   *  "FEM_PK_WITH_CUBIC_BUBBLE(N,K)" classical Lagrange element PK on a
-   *                      simplex with an additional volumic bubble function.
-   *  "FEM_PRODUCT(FEM1,FEM2)" tensorial product of two polynomial elements
-   *  "FEM_P1_NONCONFORMING" Nonconforming P1 method on a triangle.
-   *  "FEM_P1_BUBBLE_FACE(N)" P1 methd on a simplex with an additional bubble
-   *                       function on face 0.
-   *  "FEM_P1_BUBBLE_FACE_LAG" P1 methd on a simplex with an additional
-   *                           lagrange dof on face 0.   
-   *  "FEM_HERMITE_SEGMENT" Hermite element on the segment
-   *  
-   *
+   *  "FEM_PK(N,K)"                      : classical Lagrange element PK on a
+   *                                     :  simplex
+   *  "FEM_PK_DISCONTINUOUS(N,K)"        : discontinuous Lagrange element PK
+   *                                     :  on a simplex
+   *  "FEM_QK(N,K)"                      : classical Lagrange element QK on a
+   *                                     :  parellepiped
+   *  "FEM_PK_PRISM(N,K)"                : classical Lagrange element PK on a
+   *                                     :  prism
+   *  "FEM_PK_WITH_CUBIC_BUBBLE(N,K)"    : classical Lagrange element PK on a
+   *                                     :  simplex with an additional volumic
+   *                                     :  bubble function.
+   *  "FEM_PRODUCT(FEM1,FEM2)"           : tensorial product of two polynomial
+   *                                     :  elements
+   *  "FEM_P1_NONCONFORMING"             : Nonconforming P1 method on a
+   *                                     :  triangle.
+   *  "FEM_P1_BUBBLE_FACE(N)"            : P1 method on a simplex with an
+   *                                     :  additional bubble function on
+   *                                     :  face 0.
+   *  "FEM_P1_BUBBLE_FACE_LAG"           : P1 method on a simplex with an
+   *                                     :  additional lagrange dof on face 0.
+   *  "FEM_HERMITE_SEGMENT"              : Hermite element on the segment
+   *  "FEM_PK_HIERARCHICAL(N,K)"         : PK element with a hierarchical basis
+   *  "FEM_QK_HIERARCHICAL(N,K)"         : QK element with a hierarchical basis
+   *  "FEM_PK_PRISM_HIERARCHICAL(N,K)"   : PK element on a prism with a
+   *                                     :  hierarchical basis
+   *  "FEM_STRUCTURED_COMPOSITE(FEM, K)" : Composite fem on a grid with
+   *                                     :  K divisions
+   *  "FEM_PK_HIERARCHICAL_COMPOSITE(N,K,S)" : PK composite element on a grid
+   *                                     :  with S subdivisions and with a
+   *                                     : hierarchical basis
+   *  "FEM_PK_FULL_HIERARCHICAL_COMPOSITE(N,K,S)" : PK composite element with
+   *                                     :  S subdivisions and a hierarchical
+   *                                     :  basis on both degree and
+   *                                     :  subdivision
    */
 
   pfem PK_fem(size_type n, short_type k);
@@ -404,11 +402,9 @@ namespace getfem
   
   class mesh_fem;
   pfem virtual_link_fem(mesh_fem &mf1, mesh_fem &mf2,
-			bgeot::pintegration_method pim);
+			pintegration_method pim);
   pfem virtual_link_fem_with_gradient(mesh_fem &mf1, mesh_fem &mf2,
-				      bgeot::pintegration_method pim);
-  
-  //@}
+				      pintegration_method pim);
   
 }  /* end of namespace getfem.                                            */
 
