@@ -68,12 +68,13 @@ namespace getfem
       { transfert_to_G(pa, a); compute_on_face(t, pa, f); }
 
       virtual ~mat_elem_computation() {}
+      virtual size_type memsize() const = 0;
   };
 
   typedef mat_elem_computation *pmat_elem_computation;
 
   pmat_elem_computation mat_elem(pmat_elem_type pm, 
-				 bgeot::pintegration_method pi,
+				 pintegration_method pi,
 				 bgeot::pgeometric_trans pg);
 
 
