@@ -5,7 +5,7 @@ while (<F>) {
   if ($_ =~ /error has been detected/)
   {
     $er = 1;
-    print "=============================================================\n";
+    print "============================================\n";
     print $_, <F>;
   }
 }
