@@ -13,13 +13,13 @@ print TMPF "INCLINE = 0.0\n";
 print TMPF "FT = 0.1\n";
 print TMPF "MESH_TYPE = 0;\n";
 print TMPF "K = 1;\n";
+print TMPF "KI = 1;\n";
 print TMPF "INTEGRATION = 0;\n";
-print TMPF "NX = 10;\n";
+print TMPF "NX = 7;\n";
 print TMPF "RESIDU = 1E-9;\n";
 print TMPF "FEM_TYPE = 0;\n"; 
 print TMPF "ROOTFILENAME = 'laplacian';\n";
-print TMPF "\n";
-print TMPF "\n";
+print TMPF "\n\n";
 close(TMPF);
 
 
@@ -36,7 +36,7 @@ sub start_program # (N, K, NX, OPTION, SOLVER)
     if ($_ =~ /L2 error/) {
       ($a, $b) = split('=', $_);
       # print "La norme en question :", $b;
-      if ($b > 0.01) { print "Error too large\n"; $er = 1; }
+      if ($b > 0.01) { print "\nError too large\n"; $er = 1; }
     }
     if ($_ =~ /error has been detected/) {
       $er = 1;
@@ -54,18 +54,14 @@ start_program("");
 print ".";
 start_program("-d N=1 -d NX=10 -d FT=1.0");
 print ".";
-start_program("-d N=3 -d NX=5");
+start_program("-d N=3 -d NX=3 -d FT=0.01");
 print ".";
-start_program("-d N=3 -d INTEGRATION=25 -d NX=5");
-print ".";
-start_program("-d K=2 -d NX=5");
+start_program("-d N=3 -d INTEGRATION=25 -d NX=3 -d FT=0.01");
 print ".";
 start_program("-d K=2 -d NX=5");
 print ".";
 start_program("-d INTEGRATION=12");
 print ".";
-start_program("-d INTEGRATION=15");
-print ".";
 start_program("-d INTEGRATION=17");
 print ".";
 start_program("-d INTEGRATION=1  -d MESH_TYPE=1");
@@ -74,9 +70,11 @@ start_program("-d INTEGRATION=33 -d MESH_TYPE=1");
 print ".";
 start_program("-d INTEGRATION=35 -d MESH_TYPE=1");
 print ".";
-start_program("-d N=3 -d INTEGRATION=1 -d MESH_TYPE=2 -d NX=5 -d FT=0.01");
+start_program("-d N=3 -d INTEGRATION=1 -d MESH_TYPE=2 -d NX=3 -d FT=0.01");
 print ".";
-start_program("-d INTEGRATION=2 -d MESH_TYPE=1 -d INCLINE=0.5");
+start_program("-d INTEGRATION=2 -d MESH_TYPE=1 -d -d NX=10 INCLINE=0.5");
+print ".";
+start_program("-d N=1 -d FEM_TYPE=2 -d FT=1.0");
 print ".\n";
 
 `rm -f $tmp`;
